==> owncloud-8.1.0p2.tgz: owncloud/apps/files_sharing/l10n/th_TH.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "เซิร์ฟเวอร์ไปยังแชร์เซิร์ฟเวอร์ไม่ได้เปิดใช้งานบนเซิร์ฟเวอร์นี้",
    "The mountpoint name contains invalid characters." : "ชื่อจุดเชื่อมต่อมีตัวอักษรที่ไม่ถูกต้อง",
    "Invalid or untrusted SSL certificate" : "ใบรับรอง SSL ไม่ถูกต้องหรือไม่น่าเชื่อถือ",
    "Could not authenticate to remote share, password might be wrong" : "ไม่สามารถรับรองความถูกต้องจากการแชร์ระยะไกลรหัสผ่านอาจจะผิด",
    "Storage not valid" : "การจัดเก็บข้อมูลไม่ถูกต้อง",
    "Couldn't add remote share" : "ไม่สามารถเพิ่มแชร์ระยะไกล",
    "Shared with you" : "แชร์กับคุณ",
    "Shared with others" : "แชร์กับผู้อื่น",
    "Shared by link" : "แชร์โดยลิงค์",
    "Nothing shared with you yet" : "ไม่มีอะไรที่แชร์กับคุณเลย",
    "Files and folders others share with you will show up here" : "ไฟล์และโฟลเดอร์อื่นๆ ที่แชร์กับคุณจะปรากฏขึ้นที่นี่",
    "Nothing shared yet" : "ไม่มีการแชร์ใดๆ",
    "Files and folders you share will show up here" : "ไฟล์และโฟลเดอร์ที่คุณแชร์จะปรากฏขึ้นที่นี่",
    "No shared links" : "ไม่มีลิงค์ที่แชร์",
    "Files and folders you share by link will show up here" : "ไฟล์และโฟลเดอร์ที่คุณแชร์โดยลิงค์จะปรากฏขึ้นที่นี่",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "คุณต้องการที่จะเพิ่มการแชร์ระยะไกล {name} จาก {owner}@{remote}?",
    "Remote share" : "แชร์ระยะไกล",
    "Remote share password" : "รหัสผ่านการแชร์ระยะไกล",
    "Cancel" : "ยกเลิก",
    "Add remote share" : "เพิ่มการแชร์ระยะไกล",
    "You can upload into this folder" : "คุณสามารถอัพโหลดลงในโฟลเดอร์นี้",
    "No ownCloud installation (7 or higher) found at {remote}" : "ไม่มีการติดตั้ง ownCloud (7 หรือสูงกว่า) พบได้ที่ {remote}",
    "Invalid ownCloud url" : "URL ownCloud ไม่ถูกต้อง",
    "Share" : "แชร์",
    "Shared by" : "ถูกแชร์โดย",
    "A file or folder has been <strong>shared</strong>" : "ไฟล์หรือโฟลเดอร์ได้ถูก <strong>แชร์</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "ไฟล์หรือโฟลเดอร์จะถูกแชร์จาก <strong>เซิร์ฟเวอร์อื่นๆ</ strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "แชร์ไฟล์หรือโฟลเดอร์สาธารณะถูก <strong>ดาวน์โหลด</strong>",
    "You received a new remote share from %s" : "คุณได้รับการแชร์ระยะไกลใหม่จาก %s",
    "%1$s accepted remote share %2$s" : "%1$s ยอมรับการแชร์ %2$s จากระยะไกล",
    "%1$s declined remote share %2$s" : "%1$s ปฏิเสธการแชร์ %2$s จากระยะไกล",
    "%1$s unshared %2$s from you" : "%1$s ไม่ได้แชร์ %2$s จากคุณ",
    "Public shared folder %1$s was downloaded" : "โฟลเดอร์สาธารณะ %1$s ที่แชร์ถูกดาวน์โหลด",
    "Public shared file %1$s was downloaded" : "ไฟล์สาธารณะ %1$s ที่แชร์ถูกดาวน์โหลด",
    "You shared %1$s with %2$s" : "คุณแชร์ %1$s กับ %2$s",
    "You shared %1$s with group %2$s" : "คุณแชร์ %1$s กับกลุ่ม %2$s",
    "%2$s shared %1$s with you" : "%2$s ถูกแชร์ %1$s กับคุณ",
    "You shared %1$s via link" : "คุณแชร์ %1$s ผ่านลิงค์",
    "Shares" : "แชร์",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "แชร์ร่วมกับฉันผ่าน #ownCloud ด้วยไอดีคลาวด์ในเครือ สามารถดูได้ที่ %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "แชร์ร่วมกับฉันผ่าน #ownCloud ด้วยไอดีคลาวด์ในเครือ",
    "This share is password-protected" : "นี้แชร์การป้องกันด้วยรหัสผ่าน",
    "The password is wrong. Try again." : "รหัสผ่านที่ไม่ถูกต้อง กรุณาลองอีกครั้ง",
    "Password" : "รหัสผ่าน",
    "No entries found in this folder" : "ไม่พบรายการในโฟลเดอร์นี้",
    "Name" : "ชื่อ",
    "Share time" : "แชร์เวลา",
    "Sorry, this link doesn’t seem to work anymore." : "ขออภัยลิงค์นี้ดูเหมือนจะไม่ทำงานอีกต่อไป",
    "Reasons might be:" : "เหตุผลอาจจะ:",
    "the item was removed" : "รายการที่ถูกลบออก",
    "the link expired" : "ลิงค์หมดอายุ",
    "sharing is disabled" : "การแชร์ถูกปิดใช้งาน",
    "For more info, please ask the person who sent this link." : "สำหรับข้อมูลเพิ่มเติมกรุณาสอบถามผู้ที่ส่งลิงค์นี้",
    "Add to your ownCloud" : "เพิ่มลงใน ownCloud ของคุณ",
    "Download" : "ดาวน์โหลด",
    "Download %s" : "ดาวน์โหลด %s",
    "Direct link" : "ลิงค์โดยตรง",
    "Federated Cloud Sharing" : "สหพันธ์การแชร์คลาวด์",
    "Open documentation" : "เปิดเอกสาร",
    "Allow users on this server to send shares to other servers" : "อนุญาตให้ผู้ใช้บนเซิร์ฟเวอร์นี้ส่งแชร์ไปยังเซิร์ฟเวอร์อื่นๆ",
    "Allow users on this server to receive shares from other servers" : "อนุญาตให้ผู้ใช้บนเซิร์ฟเวอร์นี้ได้รับการแชร์จากเซิร์ฟเวอร์อื่นๆ",
    "Federated Cloud" : "สหพันธ์คลาวด์",
    "Your Federated Cloud ID:" : "ไอดีคลาวด์ของคุณ:",
    "Share it:" : "แชร์มัน:",
    "Add it to your website:" : "เพิ่มไปยังเว็บไซต์ของคุณ:",
    "Share with me via ownCloud" : "แชร์ร่วมกับฉันผ่าน ownCloud",
    "HTML Code:" : "โค้ด HTML:"
},
"nplurals=1; plural=0;");

==> owncloud-9.0.3.tgz: owncloud/apps/files_sharing/l10n/th_TH.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "เซิร์ฟเวอร์ไปยังแชร์เซิร์ฟเวอร์ไม่ได้เปิดใช้งานบนเซิร์ฟเวอร์นี้",
    "The mountpoint name contains invalid characters." : "ชื่อจุดเชื่อมต่อมีตัวอักษรที่ไม่ถูกต้อง",
    "Not allowed to create a federated share with the same user server" : "ไม่อนุญาตให้สร้างแชร์ในเครือกับเซิร์ฟเวอร์ที่มีผู้ใช้เดียวกัน",
    "Invalid or untrusted SSL certificate" : "ใบรับรอง SSL ไม่ถูกต้องหรือไม่น่าเชื่อถือ",
    "Could not authenticate to remote share, password might be wrong" : "ไม่สามารถรับรองความถูกต้องจากการแชร์ระยะไกลรหัสผ่านอาจจะผิด",
    "Storage not valid" : "การจัดเก็บข้อมูลไม่ถูกต้อง",
    "Couldn't add remote share" : "ไม่สามารถเพิ่มแชร์ระยะไกล",
    "Shared with you" : "แชร์กับคุณ",
    "Shared with others" : "แชร์กับผู้อื่น",
    "Shared by link" : "แชร์โดยลิงค์",
    "Federated sharing" : "แบ่งปันสหพันธ์",
    "Nothing shared with you yet" : "ไม่มีอะไรที่แชร์กับคุณเลย",
    "Files and folders others share with you will show up here" : "ไฟล์และโฟลเดอร์อื่นๆ ที่แชร์กับคุณจะปรากฏขึ้นที่นี่",
    "Nothing shared yet" : "ไม่มีการแชร์ใดๆ",
    "Files and folders you share will show up here" : "ไฟล์และโฟลเดอร์ที่คุณแชร์จะปรากฏขึ้นที่นี่",
    "No shared links" : "ไม่มีลิงค์ที่แชร์",
    "Files and folders you share by link will show up here" : "ไฟล์และโฟลเดอร์ที่คุณแชร์โดยลิงค์จะปรากฏขึ้นที่นี่",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "คุณต้องการที่จะเพิ่มการแชร์ระยะไกล {name} จาก {owner}@{remote}?",
    "Remote share" : "แชร์ระยะไกล",
    "Remote share password" : "รหัสผ่านการแชร์ระยะไกล",
    "Cancel" : "ยกเลิก",
    "Add remote share" : "เพิ่มการแชร์ระยะไกล",
    "You can upload into this folder" : "คุณสามารถอัพโหลดลงในโฟลเดอร์นี้",
    "No ownCloud installation (7 or higher) found at {remote}" : "ไม่มีการติดตั้ง ownCloud (7 หรือสูงกว่า) พบได้ที่ {remote}",
    "Invalid ownCloud url" : "URL ownCloud ไม่ถูกต้อง",
    "Shared by" : "ถูกแชร์โดย",
    "Sharing" : "การแชร์ข้อมูล",
    "A file or folder has been <strong>shared</strong>" : "ไฟล์หรือโฟลเดอร์ได้ถูก <strong>แชร์</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "ไฟล์หรือโฟลเดอร์จะถูกแชร์จาก <strong>เซิร์ฟเวอร์อื่นๆ</ strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "แชร์ไฟล์หรือโฟลเดอร์สาธารณะถูก <strong>ดาวน์โหลด</strong>",
    "You received a new remote share %2$s from %1$s" : "คุณได้รับการแชร์ระยะไกลใหม่ %2$s จาก %1$s",
    "You received a new remote share from %s" : "คุณได้รับการแชร์ระยะไกลใหม่จาก %s",
    "%1$s accepted remote share %2$s" : "%1$s ยอมรับการแชร์ %2$s จากระยะไกล",
    "%1$s declined remote share %2$s" : "%1$s ปฏิเสธการแชร์ %2$s จากระยะไกล",
    "%1$s unshared %2$s from you" : "%1$s ไม่ได้แชร์ %2$s จากคุณ",
    "Public shared folder %1$s was downloaded" : "โฟลเดอร์สาธารณะ %1$s ที่แชร์ถูกดาวน์โหลด",
    "Public shared file %1$s was downloaded" : "ไฟล์สาธารณะ %1$s ที่แชร์ถูกดาวน์โหลด",
    "You shared %1$s with %2$s" : "คุณแชร์ %1$s กับ %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s ได้แชร์ %1$s กับ %3$s",
    "You shared %1$s with group %2$s" : "คุณแชร์ %1$s กับกลุ่ม %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s ได้แชร์ %1$s กับกลุ่ม %3$s",
    "%2$s shared %1$s via link" : "%2$s ได้แชร์ %1$s ผ่านลิงค์",
    "You shared %1$s via link" : "คุณแชร์ %1$s ผ่านลิงค์",
    "%2$s shared %1$s with you" : "%2$s ถูกแชร์ %1$s กับคุณ",
    "Downloaded via public link" : "ดาวน์โหลดผ่านลิงค์สาธารณะ",
    "Shared with %2$s" : "แชร์กับ %2$s",
    "Shared with %3$s by %2$s" : "แชร์กับ %3$s โดย %2$s",
    "Shared with group %2$s" : "แชร์กับกลุ่ม %2$s",
    "Shared with group %3$s by %2$s" : "แชร์กับกลุ่ม %3$s โดย %2$s",
    "Shared via link by %2$s" : "แชร์ผ่านลิงค์โดย %2$s",
    "Shared via public link" : "แชร์ผ่านลิงค์สาธารณะ",
    "Shared by %2$s" : "แชร์โดย %2$s",
    "Shares" : "แชร์",
    "Accept" : "ยอมรับ",
    "Decline" : "ลดลง",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "แชร์ร่วมกับฉันผ่าน #ownCloud ด้วยไอดีคลาวด์ในเครือ สามารถดูได้ที่ %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "แชร์ร่วมกับฉันผ่าน #ownCloud ด้วยไอดีคลาวด์ในเครือ",
    "This share is password-protected" : "นี้แชร์การป้องกันด้วยรหัสผ่าน",
    "The password is wrong. Try again." : "รหัสผ่านที่ไม่ถูกต้อง กรุณาลองอีกครั้ง",
    "Password" : "รหัสผ่าน",
    "No entries found in this folder" : "ไม่พบรายการในโฟลเดอร์นี้",
    "Name" : "ชื่อ",
    "Share time" : "แชร์เวลา",
    "Sorry, this link doesn’t seem to work anymore." : "ขออภัยลิงค์นี้ดูเหมือนจะไม่ทำงานอีกต่อไป",
    "Reasons might be:" : "เหตุผลอาจจะ:",
    "the item was removed" : "รายการที่ถูกลบออก",
    "the link expired" : "ลิงค์หมดอายุ",
    "sharing is disabled" : "การแชร์ถูกปิดใช้งาน",
    "For more info, please ask the person who sent this link." : "สำหรับข้อมูลเพิ่มเติมกรุณาสอบถามผู้ที่ส่งลิงค์นี้",
    "Add to your ownCloud" : "เพิ่มลงใน ownCloud ของคุณ",
    "Download" : "ดาวน์โหลด",
    "Download %s" : "ดาวน์โหลด %s",
    "Direct link" : "ลิงค์โดยตรง",
    "Federated Cloud Sharing" : "สหพันธ์การแชร์คลาวด์",
    "Open documentation" : "เปิดเอกสาร",
    "Allow users on this server to send shares to other servers" : "อนุญาตให้ผู้ใช้บนเซิร์ฟเวอร์นี้ส่งแชร์ไปยังเซิร์ฟเวอร์อื่นๆ",
    "Allow users on this server to receive shares from other servers" : "อนุญาตให้ผู้ใช้บนเซิร์ฟเวอร์นี้ได้รับการแชร์จากเซิร์ฟเวอร์อื่นๆ",
    "Federated Cloud" : "สหพันธ์คลาวด์",
    "Your Federated Cloud ID:" : "ไอดีคลาวด์ของคุณ:",
    "Share it:" : "แชร์มัน:",
    "Add to your website" : "เพิ่มไปยังเว็บไซต์",
    "Share with me via ownCloud" : "แชร์ร่วมกับฉันผ่าน ownCloud",
    "HTML Code:" : "โค้ด HTML:",
    "Public shared file %1$s was downloaded" : "ไฟล์สาธารณะ %1$s ที่แชร์ถูกดาวน์โหลด",
    "Public shared folder %1$s was downloaded" : "โฟลเดอร์สาธารณะ %1$s ที่แชร์ถูกดาวน์โหลด",
    "Shared by %2$s" : "แชร์โดย %2$s",
    "Shared via link by %2$s" : "แชร์ผ่านลิงค์โดย %2$s",
    "Shared with group %3$s by %2$s" : "แชร์กับกลุ่ม %3$s โดย %2$s"
},
"nplurals=1; plural=0;");
